2014.10.28
==========
----

* Feature: Add ``MANIFEST.in`` file.
* Feature: Add ``README.rst`` file.
* Feature: Add ``LICENSE`` file.
* Feature: Add ``ChangeLog.rst`` file.
* Feature: Add ``AUTHORS.rst`` file.
* Feature: Add  Python3 support.
* Feature: Add command line interface.
* Feature: Register/Upload the package in PyPi.


